@@ -29,7 +29,12 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.Paths;
+import java.util.stream.Stream;
 
 import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.archivers.arj.ArjArchiveInputStream;
@@ -39,10 +44,11 @@ import org.apache.commons.compress.archivers.jar.JarArchiveInputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
 import org.apache.commons.compress.utils.ByteUtils;
-import org.apache.commons.compress.utils.CharsetNames;
 import org.apache.commons.io.input.BrokenInputStream;
 import org.apache.commons.lang3.reflect.FieldUtils;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.MethodSource;
 
 public class ArchiveStreamFactoryTest extends AbstractTest {
 
@@ -75,11 +81,11 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
 
     private static final ArchiveStreamFactory FACTORY = ArchiveStreamFactory.DEFAULT;
 
-    private static final ArchiveStreamFactory FACTORY_UTF8 = new ArchiveStreamFactory(CharsetNames.UTF_8);
+    private static final ArchiveStreamFactory FACTORY_UTF8 = new ArchiveStreamFactory(StandardCharsets.UTF_8.name());
 
     private static final ArchiveStreamFactory FACTORY_ASCII = new ArchiveStreamFactory(StandardCharsets.US_ASCII.name());
 
-    private static final ArchiveStreamFactory FACTORY_SET_UTF8 = getFactory(CharsetNames.UTF_8);
+    private static final ArchiveStreamFactory FACTORY_SET_UTF8 = getFactory(StandardCharsets.UTF_8.name());
 
     private static final ArchiveStreamFactory FACTORY_SET_ASCII = getFactory(StandardCharsets.US_ASCII.name());
 
@@ -88,23 +94,23 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
      */
     private static final String ARJ_DEFAULT;
     private static final String DUMP_DEFAULT;
-    private static final String ZIP_DEFAULT = getField(new ZipArchiveInputStream(null));
-    private static final String CPIO_DEFAULT = getField(new CpioArchiveInputStream(null));
-    private static final String TAR_DEFAULT = getField(new TarArchiveInputStream(null));
-    private static final String JAR_DEFAULT = getField(new JarArchiveInputStream(null));
+    private static final String ZIP_DEFAULT = getCharsetName(new ZipArchiveInputStream(null));
+    private static final String CPIO_DEFAULT = getCharsetName(new CpioArchiveInputStream(null));
+    private static final String TAR_DEFAULT = getCharsetName(new TarArchiveInputStream(null));
+    private static final String JAR_DEFAULT = getCharsetName(new JarArchiveInputStream(null));
 
     static {
         String dflt;
         dflt = UNKNOWN;
         try (ArjArchiveInputStream inputStream = new ArjArchiveInputStream(newInputStream("bla.arj"))) {
-            dflt = getField(inputStream);
+            dflt = getCharsetName(inputStream);
         } catch (final Exception e) {
             e.printStackTrace();
         }
         ARJ_DEFAULT = dflt;
         dflt = UNKNOWN;
         try (DumpArchiveInputStream inputStream = new DumpArchiveInputStream(newInputStream("bla.dump"))) {
-            dflt = getField(inputStream);
+            dflt = getCharsetName(inputStream);
         } catch (final Exception e) {
             e.printStackTrace();
         }
@@ -112,40 +118,40 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     static final TestData[] TESTS = { new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, ARJ_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
+            new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charsetName"),
             new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
+            new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charsetName"),
             new TestData("bla.arj", ArchiveStreamFactory.ARJ, false, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"),
 
             new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, CPIO_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
+            new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charsetName"),
             new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
+            new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charsetName"),
             new TestData("bla.cpio", ArchiveStreamFactory.CPIO, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"),
 
             new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, DUMP_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
+            new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charsetName"),
             new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
+            new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charsetName"),
             new TestData("bla.dump", ArchiveStreamFactory.DUMP, false, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"),
 
             new TestData("bla.tar", ArchiveStreamFactory.TAR, true, TAR_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.tar", ArchiveStreamFactory.TAR, true, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
+            new TestData("bla.tar", ArchiveStreamFactory.TAR, true, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charsetName"),
             new TestData("bla.tar", ArchiveStreamFactory.TAR, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.tar", ArchiveStreamFactory.TAR, true, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
+            new TestData("bla.tar", ArchiveStreamFactory.TAR, true, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charsetName"),
             new TestData("bla.tar", ArchiveStreamFactory.TAR, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"),
 
-            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, JAR_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
-            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
-            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"),
+            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, JAR_DEFAULT, FACTORY, "charset"),
+            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charset"),
+            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charset"),
+            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charset"),
+            new TestData("bla.jar", ArchiveStreamFactory.JAR, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charset"),
 
-            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, ZIP_DEFAULT, FACTORY, "charsetName"),
-            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, CharsetNames.UTF_8, FACTORY_UTF8, "charsetName"),
-            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charsetName"),
-            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, CharsetNames.UTF_8, FACTORY_SET_UTF8, "charsetName"),
-            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charsetName"), };
+            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, ZIP_DEFAULT, FACTORY, "charset"),
+            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.UTF_8.name(), FACTORY_UTF8, "charset"),
+            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.US_ASCII.name(), FACTORY_ASCII, "charset"),
+            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charset"),
+            new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charset"), };
 
     /** equals allowing null. */
     private static boolean eq(final String exp, final String act) {
@@ -155,6 +161,10 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         return exp.equals(act);
     }
 
+    private static String getCharsetName(final ArchiveInputStream<?> instance) {
+        return instance.getCharset().name();
+    }
+
     @SuppressWarnings("deprecation") // test of deprecated method
     static ArchiveStreamFactory getFactory(final String entryEncoding) {
         final ArchiveStreamFactory fac = new ArchiveStreamFactory();
@@ -162,27 +172,35 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         return fac;
     }
 
-    private static String getField(final ArchiveInputStream<?> instance) {
-        return instance.getCharset().name();
-    }
-
-    private static String getField(final Object instance, final String name) {
+    private static String getFieldAsString(final Object instance, final String name) {
         if (instance instanceof ArchiveInputStream) {
-            return getField((ArchiveInputStream<?>) instance);
+            return getCharsetName((ArchiveInputStream<?>) instance);
         }
         try {
             final Object object = FieldUtils.readField(instance, name, true);
-            if (object instanceof String || object == null) {
+            if (object == null) {
+                return null;
+            }
+            if (object instanceof String) {
+                // For example "charsetName"
                 return (String) object;
             }
-            System.out.println("Wrong type: " + object.getClass().getCanonicalName() + " for " + name + " in class " + instance.getClass().getSimpleName());
-            return UNKNOWN;
+            if (object instanceof Charset) {
+                // For example "charset"
+                return ((Charset) object).name();
+            }
+            // System.out.println("Wrong type: " + object.getClass().getCanonicalName() + " for " + name + " in class " + instance.getClass().getSimpleName());
+            return object.toString();
         } catch (final IllegalAccessException e) {
             System.out.println("Cannot find " + name + " in class " + instance.getClass().getSimpleName());
             return UNKNOWN;
         }
     }
 
+    public static Stream<Path> getIcoPathStream() throws IOException {
+        return Files.walk(Paths.get("src/test/resources/org/apache/commons/compress/ico")).filter(Files::isRegularFile);
+    }
+
     private String detect(final String resource) throws IOException, ArchiveException {
         try (InputStream in = new BufferedInputStream(newInputStream(resource))) {
             return ArchiveStreamFactory.detect(in);
@@ -283,8 +301,8 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         assertNull(fac.getEntryEncoding());
         fac = new ArchiveStreamFactory(null);
         assertNull(fac.getEntryEncoding());
-        fac = new ArchiveStreamFactory(CharsetNames.UTF_8);
-        assertEquals(CharsetNames.UTF_8, fac.getEntryEncoding());
+        fac = new ArchiveStreamFactory(StandardCharsets.UTF_8.name());
+        assertEquals(StandardCharsets.UTF_8.name(), fac.getEntryEncoding());
     }
 
     @Test
@@ -292,13 +310,14 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     public void testEncodingDeprecated() {
         final ArchiveStreamFactory fac1 = new ArchiveStreamFactory();
         assertNull(fac1.getEntryEncoding());
-        fac1.setEntryEncoding(CharsetNames.UTF_8);
-        assertEquals(CharsetNames.UTF_8, fac1.getEntryEncoding());
-        fac1.setEntryEncoding(CharsetNames.US_ASCII);
-        assertEquals(CharsetNames.US_ASCII, fac1.getEntryEncoding());
-        final ArchiveStreamFactory fac2 = new ArchiveStreamFactory(CharsetNames.UTF_8);
-        assertEquals(CharsetNames.UTF_8, fac2.getEntryEncoding());
-        assertThrows(IllegalStateException.class, () -> fac2.setEntryEncoding("US_ASCII"), "Expected IllegalStateException");
+        fac1.setEntryEncoding(StandardCharsets.UTF_8.name());
+        assertEquals(StandardCharsets.UTF_8.name(), fac1.getEntryEncoding());
+        fac1.setEntryEncoding(StandardCharsets.US_ASCII.name());
+        assertEquals(StandardCharsets.US_ASCII.name(), fac1.getEntryEncoding());
+        final ArchiveStreamFactory fac2 = new ArchiveStreamFactory(StandardCharsets.UTF_8.name());
+        assertEquals(StandardCharsets.UTF_8.name(), fac2.getEntryEncoding());
+        fac2.setEntryEncoding(StandardCharsets.US_ASCII.name());
+        assertEquals(StandardCharsets.US_ASCII.name(), fac2.getEntryEncoding());
     }
 
     @Test
@@ -307,7 +326,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         for (int i = 1; i <= TESTS.length; i++) {
             final TestData test = TESTS[i - 1];
             try (ArchiveInputStream<?> ais = getInputStream(test.type, test.testFile, test.fac)) {
-                final String field = getField(ais);
+                final String field = getCharsetName(ais);
                 if (!eq(test.expectedEncoding, field)) {
                     System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                     failed++;
@@ -325,7 +344,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         for (int i = 1; i <= TESTS.length; i++) {
             final TestData test = TESTS[i - 1];
             try (ArchiveInputStream<?> ais = getInputStream(test.testFile, test.fac)) {
-                final String field = getField(ais);
+                final String field = getCharsetName(ais);
                 if (!eq(test.expectedEncoding, field)) {
                     System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                     failed++;
@@ -344,7 +363,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
             final TestData test = TESTS[i - 1];
             if (test.hasOutputStream) {
                 try (ArchiveOutputStream<?> ais = getOutputStream(test.type, test.fac)) {
-                    final String field = getField(ais, test.fieldName);
+                    final String field = getFieldAsString(ais, test.fieldName);
                     if (!eq(test.expectedEncoding, field)) {
                         System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                         failed++;
@@ -357,6 +376,23 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         }
     }
 
+    @ParameterizedTest
+    @MethodSource("getIcoPathStream")
+    public void testIcoFilesAreNoTARs(final Path path) throws Exception {
+        try (InputStream fis = Files.newInputStream(path);
+                InputStream is = new BufferedInputStream(fis)) {
+            final ArchiveException ae = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.detect(is),
+                    "created an input stream for a non-archive");
+            assertTrue(ae.getMessage().startsWith("No Archiver found"));
+        }
+        try (InputStream fis = Files.newInputStream(path);
+                InputStream is = new BufferedInputStream(fis)) {
+            final ArchiveException ae = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.DEFAULT.createArchiveInputStream(is),
+                    "created an input stream for a non-archive");
+            assertTrue(ae.getMessage().startsWith("No Archiver found"));
+        }
+    }
+
     /**
      * See https://issues.apache.org/jira/browse/COMPRESS-171
      */
